#
# spec file for package perl-App-Dochazka-REST
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name App-Dochazka-REST
Name:           perl-App-Dochazka-REST
Version:        0.559
Release:        2.5
Summary:        Dochazka REST server
License:        BSD-3-Clause
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        App-Dochazka-REST-0.559.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(App::CELL) >= 0.215
BuildRequires:  perl(App::Dochazka::Common) >= 0.205
BuildRequires:  perl(Authen::Passphrase::SaltedDigest) >= 0.008
BuildRequires:  perl(DBD::Pg)
BuildRequires:  perl(DBI)
BuildRequires:  perl(DBIx::Connector) >= 0.47
BuildRequires:  perl(Date::Calc)
BuildRequires:  perl(Date::Holidays::CZ) >= 0.12
BuildRequires:  perl(File::ShareDir) >= 1
BuildRequires:  perl(File::ShareDir::Install) >= 0.11
BuildRequires:  perl(File::Slurp)
BuildRequires:  perl(HTTP::Request)
BuildRequires:  perl(JSON)
BuildRequires:  perl(Mason)
BuildRequires:  perl(Module::Build)
BuildRequires:  perl(Params::Validate) >= 1.06
BuildRequires:  perl(Path::Router) >= 0.12
BuildRequires:  perl(Plack::Middleware::Session)
BuildRequires:  perl(Plack::Middleware::StackTrace)
BuildRequires:  perl(Plack::Runner)
BuildRequires:  perl(Plack::Test)
BuildRequires:  perl(Pod::Simple::HTML)
BuildRequires:  perl(Test::Deep::NoTest)
BuildRequires:  perl(Test::Fatal)
BuildRequires:  perl(Test::JSON)
BuildRequires:  perl(Test::Warnings)
BuildRequires:  perl(Try::Tiny)
BuildRequires:  perl(Web::MREST) >= 0.287
BuildRequires:  perl(Web::MREST::CLI) >= 0.276
BuildRequires:  perl(Web::Machine) >= 0.15
Requires:       perl(App::CELL) >= 0.215
Requires:       perl(App::Dochazka::Common) >= 0.207
Requires:       perl(Authen::Passphrase::SaltedDigest) >= 0.008
Requires:       perl(DBD::Pg)
Requires:       perl(DBI)
Requires:       perl(DBIx::Connector) >= 0.47
Requires:       perl(Date::Calc)
Requires:       perl(Date::Holidays::CZ) >= 0.12
Requires:       perl(File::ShareDir) >= 1
Requires:       perl(JSON)
Requires:       perl(Mason)
Requires:       perl(Params::Validate) >= 1.06
Requires:       perl(Path::Router) >= 0.12
Requires:       perl(Plack::Middleware::Session)
Requires:       perl(Plack::Middleware::StackTrace)
Requires:       perl(Plack::Runner)
Requires:       perl(Pod::Simple::HTML)
Requires:       perl(Test::Deep::NoTest)
Requires:       perl(Try::Tiny)
Requires:       perl(Web::MREST) >= 0.287
Requires:       perl(Web::MREST::CLI) >= 0.276
Requires:       perl(Web::Machine) >= 0.15
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  systemd
BuildRequires:  perl(Starman)
Requires:       perl(Starman)
Requires(pre):  /usr/sbin/groupadd
Requires(pre):  /usr/sbin/useradd
Provides:       group(dochazka-rest)
Provides:       user(dochazka-rest)
%{?systemd_requires}

%pre
getent group dochazka-rest >/dev/null || groupadd -r dochazka-rest
getent passwd dochazka-rest >/dev/null || useradd -r -g dochazka-rest -d %{_localstatedir}/lib/dochazka-rest -s /sbin/nologin -c "user for dochazka REST" dochazka-rest
%service_add_pre dochazka-rest.service

%preun
%service_del_preun dochazka-rest.service

%postun
%service_del_postun dochazka-rest.service

%post
%service_add_post dochazka-rest.service
# MANUAL END

%description
This distribution, App::Dochazka::REST, including all the modules in
'lib/', the scripts in 'bin/', and the configuration files in 'config/',
constitutes the REST server (API) component of Dochazka, the open-source
Attendance/Time Tracking (ATT) system.

Dochazka as a whole aims to be a convenient, open-source ATT solution.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Build.PL installdirs=vendor
./Build build flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
# MANUAL BEGIN
install -dm0755 %{buildroot}%{_sysconfdir}/dochazka-rest
install -m0640 ext/REST_SiteConfig.pm.example %{buildroot}%{_sysconfdir}/dochazka-rest/REST_SiteConfig.pm
install -m0640 ext/REST_SiteConfig.pm.example %{buildroot}%{_sysconfdir}/dochazka-rest/REST_SiteConfig.pm.example
install -dm0755 %{buildroot}%{_localstatedir}/lib/dochazka-rest
install -dm0755 %{buildroot}%{_localstatedir}/log/dochazka
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_unitdir}
ln -sf service %{buildroot}%{_sbindir}/rcdochazka-rest
install -m0644 ext/systemd/dochazka-rest.service %{buildroot}%{_unitdir}/dochazka-rest.service

echo "%dir %{_sysconfdir}/dochazka-rest" >> %{name}.files
echo "%config(noreplace) %attr(0640,dochazka-rest,dochazka-rest) %{_sysconfdir}/dochazka-rest/REST_SiteConfig.pm" >> %{name}.files
echo "%config %attr(0640,dochazka-rest,dochazka-rest) %{_sysconfdir}/dochazka-rest/REST_SiteConfig.pm.example" >> %{name}.files
echo "%attr(0750,dochazka-rest,dochazka-rest) %dir %{_localstatedir}/lib/dochazka-rest" >> %{name}.files
echo "%attr(0750,dochazka-rest,dochazka-rest) %dir %{_localstatedir}/log/dochazka" >> %{name}.files
echo "%{_sbindir}/rcdochazka-rest" >> %{name}.files
echo "%{_unitdir}/dochazka-rest.service" >> %{name}.files
# MANUAL END
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README.rst run-tests.sh version.plx WISHLIST
%license LICENSE

%changelog
* Wed Mar 27 2024 Nathan Cutler <ncutler@suse.com>
- spec:
  + add user() and group() provides (boo#1221423)
* Wed Jun 29 2022 Nathan Cutler <ncutler@suse.com>
- updated to 0.559
  see /usr/share/doc/packages/perl-App-Dochazka-REST/Changes
* Fri Feb 14 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Tue Feb 11 2020 Nathan Cutler <ncutler@suse.com>
- updated to 0.558
  see /usr/share/doc/packages/perl-App-Dochazka-REST/Changes
* Fri Oct 20 2017 ncutler@suse.com
- updated to 0.551
  see /usr/share/doc/packages/perl-App-Dochazka-REST/Changes
* Mon Oct 16 2017 ncutler@suse.com
- updated to 0.550
  see /usr/share/doc/packages/perl-App-Dochazka-REST/Changes
* Tue Nov  1 2016 ncutler@suse.com
- updated to 0.548
  see /usr/share/doc/packages/perl-App-Dochazka-REST/Changes
* Mon Sep 26 2016 ncutler@suse.com
- updated to 0.547
  see /usr/share/doc/packages/perl-App-Dochazka-REST/Changes
* Sun Sep 25 2016 ncutler@suse.com
- updated to 0.546
  see /usr/share/doc/packages/perl-App-Dochazka-REST/Changes
* Fri Sep 23 2016 ncutler@suse.com
- updated to 0.545
  see /usr/share/doc/packages/perl-App-Dochazka-REST/Changes
* Sun Sep 18 2016 ncutler@suse.com
- updated to 0.544
  see /usr/share/doc/packages/perl-App-Dochazka-REST/Changes
* Sat Sep 17 2016 ncutler@suse.com
- updated to 0.543
  see /usr/share/doc/packages/perl-App-Dochazka-REST/Changes
* Thu Sep 15 2016 ncutler@suse.com
- updated to 0.542
  see /usr/share/doc/packages/perl-App-Dochazka-REST/Changes
* Wed Sep 14 2016 tampakrap@opensuse.org
- add example and empty config files
* Wed Sep 14 2016 ncutler@suse.com
- updated to 0.541
  see /usr/share/doc/packages/perl-App-Dochazka-REST/Changes
* Tue Sep 13 2016 ncutler@suse.com
- updated to 0.540
  see /usr/share/doc/packages/perl-App-Dochazka-REST/Changes
* Tue Sep 13 2016 ncutler@suse.com
- updated to 0.539
  see /usr/share/doc/packages/perl-App-Dochazka-REST/Changes
* Mon Sep 12 2016 ncutler@suse.com
- updated to 0.538
  see /usr/share/doc/packages/perl-App-Dochazka-REST/Changes
* Sun Sep 11 2016 ncutler@suse.com
- updated to 0.537
  see /usr/share/doc/packages/perl-App-Dochazka-REST/Changes
* Thu Sep  8 2016 tampakrap@opensuse.org
- updated to 0.536
  see /usr/share/doc/packages/perl-App-Dochazka-REST/Changes
- add perl(Starman) dependency
- systemd unit file moved to ext/
- rename the dochazka user to dochazka-rest
* Wed Sep  7 2016 tampakrap@opensuse.org
- generate the spec fully from cpanspec.yml
- create /var/{log,lib}/dochazka with dockazka:dochazka ownership
- create /etc/dochazka-rest (currently empty, will be populated with sample
  config file)
- add systemd unit file
* Mon Sep  5 2016 ncutler@suse.com
- updated to 0.535
  see /usr/share/doc/packages/perl-App-Dochazka-REST/Changes
* Thu Dec 10 2015 ncutler@suse.com
- spec: drop postgresql dependency, consolidate readmes into
  README.rst
* Wed Jul 29 2015 ncutler@suse.com
- update dependencies
* Sat Jul 25 2015 ncutler@suse.com
- refrain from packaging release script
* Tue Jul 21 2015 ncutler@suse.com
- regenerate spec file and forward port mods
* Tue Jul 21 2015 ncutler@suse.com
- updated to 0.467
* Tue Jul 21 2015 ncutler@suse.com
- add _service file for automatic updating of spec file version number
- Update to 0.467
* Sun Jul 12 2015 ncutler@suse.com
- Update to 0.466
* Thu Jul  9 2015 ncutler@suse.com
- Update to 0.463
* Wed Jul  8 2015 ncutler@suse.com
- Update to 0.462
* Sun Jul  5 2015 ncutler@suse.com
- spec file: add %%pre to create dochazka group and user
* Sun Jul  5 2015 ncutler@suse.com
- Update to 0.459
* Sun Jul  5 2015 ncutler@suse.com
- Update to 0.458
* Sat Jul  4 2015 ncutler@suse.com
- Update to 0.457
* Sat Jul  4 2015 ncutler@suse.com
- Update to 0.456
* Sat Jul  4 2015 ncutler@suse.com
- Update to 0.455
* Sat Jul  4 2015 ncutler@suse.com
- Update to 0.454
* Sat Jul  4 2015 ncutler@suse.com
- Update to 0.453
* Fri Jul  3 2015 ncutler@suse.com
- Update to 0.452
* Fri Jul  3 2015 ncutler@suse.com
- Update to 0.451
* Sun Jun 28 2015 ncutler@suse.com
- Update to 0.449
* Sun Jun 28 2015 ncutler@suse.com
- Update to 0.448
* Sun Jun 28 2015 ncutler@suse.com
- Update to 0.447
* Mon May 18 2015 ncutler@suse.com
- Update to 0.444
* Sun Apr 19 2015 ncutler@suse.com
- Update to 0.443
* Sat Apr 18 2015 ncutler@suse.com
- Update to 0.442
* Sat Apr 18 2015 ncutler@suse.com
- Update to 0.441
* Sat Apr 18 2015 ncutler@suse.com
- Update to 0.438
* Fri Apr 17 2015 ncutler@suse.com
- Update to 0.434
* Thu Apr 16 2015 ncutler@suse.com
- Update to 0.433
* Thu Apr 16 2015 ncutler@suse.com
- Update to 0.432
* Thu Apr 16 2015 ncutler@suse.com
- Update to 0.431
* Wed Apr 15 2015 ncutler@suse.com
- fix spec file
* Tue Apr 14 2015 ncutler@suse.com
- Update to 0.429
* Tue Apr 14 2015 ncutler@suse.com
- Update to 0.428
* Thu Apr  9 2015 ncutler@suse.com
- re-generate spec file to fix dependencies
* Tue Apr  7 2015 ncutler@suse.com
- Update to 0.427
* Mon Mar 30 2015 ncutler@suse.com
- Update to 0.415
* Wed Mar 25 2015 ncutler@suse.com
- Update to 0.414
* Mon Feb 16 2015 ncutler@suse.com
- Update to 0.400
* Mon Feb 16 2015 ncutler@suse.com
- Update to 0.399
* Fri Feb 13 2015 ncutler@suse.com
- Update to 0.396
* Thu Feb 12 2015 ncutler@suse.com
- Update to 0.389
* Thu Feb 12 2015 ncutler@suse.com
- Update to 0.388
* Thu Feb 12 2015 ncutler@suse.com
- Update to 0.387
* Thu Feb 12 2015 ncutler@suse.com
- Update to 0.386
* Thu Feb 12 2015 ncutler@suse.com
- Update to 0.385
* Wed Feb 11 2015 ncutler@suse.com
- Update to 0.383
* Wed Feb 11 2015 ncutler@suse.com
- Update to 0.382
* Mon Feb  2 2015 ncutler@suse.com
- Update to 0.363
* Mon Feb  2 2015 ncutler@suse.com
- Update to 0.362
* Thu Dec 18 2014 ncutler@suse.com
- Update to 0.356
* Fri Dec 12 2014 ncutler@suse.com
- Update to 0.349
* Fri Dec 12 2014 ncutler@suse.com
- Update to 0.348
* Thu Dec 11 2014 ncutler@suse.com
- Update to 0.346
* Wed Dec 10 2014 ncutler@suse.com
- Update to 0.343
* Tue Dec  9 2014 ncutler@suse.com
- Update to 0.341
* Mon Dec  8 2014 ncutler@suse.com
- Update to 0.338
* Mon Dec  8 2014 ncutler@suse.com
- Update to 0.337
* Sat Dec  6 2014 ncutler@suse.com
- Update to 0.334
* Sat Dec  6 2014 ncutler@suse.com
- Update to 0.333
* Fri Dec  5 2014 ncutler@suse.com
- Update to 0.329
* Wed Dec  3 2014 ncutler@suse.com
- Update to 0.326
* Fri Nov 28 2014 ncutler@suse.com
- Update to 0.319
* Fri Nov 28 2014 ncutler@suse.com
- Update to 0.318
* Fri Nov 28 2014 ncutler@suse.com
- Update to 0.317
* Fri Nov 28 2014 ncutler@suse.com
- Update to 0.316
* Fri Nov 28 2014 ncutler@suse.com
- Update to 0.315
* Fri Nov 28 2014 ncutler@suse.com
- Update to 0.314
* Fri Nov 28 2014 ncutler@suse.com
- Update to 0.313
* Mon Nov 24 2014 ncutler@suse.com
- Update to 0.303
* Mon Nov 24 2014 ncutler@suse.com
- Update to 0.302
* Sun Nov 23 2014 ncutler@suse.com
- Update to 0.300
* Sun Nov 23 2014 ncutler@suse.com
- Update to 0.299
* Thu Nov 20 2014 ncutler@suse.com
- Update to 0.297
* Thu Nov 20 2014 ncutler@suse.com
- Update to 0.296
* Wed Nov 19 2014 ncutler@suse.com
- Update to 0.292
* Wed Nov 19 2014 ncutler@suse.com
- Update to 0.291
* Wed Nov 19 2014 ncutler@suse.com
- Update to 0.290
* Wed Nov 19 2014 ncutler@suse.com
- Update to 0.289
* Tue Nov 18 2014 ncutler@suse.com
- Update to 0.287
* Tue Nov 18 2014 ncutler@suse.com
- Update to 0.286
* Tue Nov 18 2014 ncutler@suse.com
- Update to 0.285
* Fri Nov 14 2014 ncutler@suse.com
- Update to 0.281
* Fri Nov 14 2014 ncutler@suse.com
- Update to 0.280
* Thu Nov 13 2014 ncutler@suse.com
- Update to 0.277
* Thu Nov 13 2014 ncutler@suse.com
- Update to 0.275
* Wed Nov 12 2014 ncutler@suse.com
- Update to 0.273
* Wed Nov 12 2014 ncutler@suse.com
- Update to 0.272
* Wed Nov 12 2014 ncutler@suse.com
- Update to 0.271
* Wed Nov 12 2014 ncutler@suse.com
- Update to 0.270
* Wed Nov 12 2014 ncutler@suse.com
- Update to 0.269
* Wed Nov 12 2014 ncutler@suse.com
- Update to 0.268
* Mon Nov 10 2014 ncutler@suse.com
- Update to 0.264
* Mon Nov 10 2014 ncutler@suse.com
- Update to 0.263
* Mon Nov 10 2014 ncutler@suse.com
- Update to 0.262
* Mon Nov 10 2014 ncutler@suse.com
- Update to 0.261
* Mon Nov 10 2014 ncutler@suse.com
- Update to 0.260
* Fri Nov  7 2014 ncutler@suse.com
- Update to 0.254
* Thu Nov  6 2014 ncutler@suse.com
- Update to 0.252
* Wed Nov  5 2014 ncutler@suse.com
- Update to 0.249
* Tue Nov  4 2014 ncutler@suse.com
- Update to 0.245
* Tue Nov  4 2014 ncutler@suse.com
- Update to 0.244
* Tue Nov  4 2014 ncutler@suse.com
- Update to 0.243
* Mon Nov  3 2014 ncutler@suse.com
- Update to 0.240
* Fri Oct 31 2014 ncutler@suse.com
- Update to 0.235
* Fri Oct 31 2014 ncutler@suse.com
- Update to 0.234
* Fri Oct 31 2014 ncutler@suse.com
- Update to 0.233
* Thu Oct 30 2014 ncutler@suse.com
- Update to 0.230
* Wed Oct 29 2014 ncutler@suse.com
- Update to 0.228
* Wed Oct 29 2014 ncutler@suse.com
- Update to 0.227
* Wed Oct 29 2014 ncutler@suse.com
- Update to 0.226
* Wed Oct 29 2014 ncutler@suse.com
- require App::Dochazka 0.172
* Mon Oct 27 2014 ncutler@suse.com
- Update to 0.217
* Mon Oct 27 2014 ncutler@suse.com
- Update to 0.216
* Mon Oct 27 2014 ncutler@suse.com
- Update to 0.215
* Mon Oct 27 2014 ncutler@suse.com
- Update to 0.214
* Fri Oct 24 2014 ncutler@suse.com
- Update to 0.210
* Fri Oct 24 2014 ncutler@suse.com
- Update to 0.209
* Thu Oct 23 2014 ncutler@suse.com
- Update to 0.207
* Thu Oct 23 2014 ncutler@suse.com
- Update to 0.206
* Thu Oct 23 2014 ncutler@suse.com
- Update to 0.205
* Wed Oct 22 2014 ncutler@suse.com
- Update to 0.202
* Wed Oct 22 2014 ncutler@suse.com
- Update to 0.201
* Tue Oct 21 2014 ncutler@suse.com
- Update to 0.199
* Tue Oct 21 2014 ncutler@suse.com
- Update to 0.198
* Tue Oct 21 2014 ncutler@suse.com
- Update to 0.197
* Tue Oct 21 2014 ncutler@suse.com
- Update to 0.196
* Tue Oct 21 2014 ncutler@suse.com
- Update to 0.195
* Tue Oct 21 2014 ncutler@suse.com
- Update to 0.194
* Mon Oct 20 2014 ncutler@suse.com
- Update to 0.191
* Fri Oct 17 2014 ncutler@suse.com
- Update to 0.190
* Fri Oct 17 2014 ncutler@suse.com
- Update to 0.189
* Thu Oct 16 2014 ncutler@suse.com
- Update to 0.186
* Thu Oct 16 2014 ncutler@suse.com
- fixed spec file
* Thu Oct 16 2014 ncutler@suse.com
- Update to 0.185
* Thu Oct 16 2014 ncutler@suse.com
- Update to 0.184
* Thu Oct 16 2014 ncutler@suse.com
- Update to 0.183
* Thu Oct 16 2014 ncutler@suse.com
- Update to 0.182
* Wed Oct 15 2014 ncutler@suse.com
- Update to 0.178
* Tue Oct 14 2014 ncutler@suse.com
- Update to 0.176
* Wed Sep 24 2014 ncutler@suse.com
- Update to 0.174
* Wed Sep 24 2014 ncutler@suse.com
- Update to 0.173
* Wed Sep 17 2014 ncutler@suse.com
- Update to 0.172
* Wed Sep 17 2014 ncutler@suse.com
- Update to 0.171
* Wed Sep 17 2014 ncutler@suse.com
- Update to 0.170
* Tue Sep  9 2014 ncutler@suse.com
- Update to 0.168
* Mon Sep  1 2014 ncutler@suse.com
- Update to 0.166
* Mon Sep  1 2014 ncutler@suse.com
- Update to 0.165
* Tue Aug 19 2014 ncutler@suse.com
- Update to 0.161
* Mon Aug 18 2014 ncutler@suse.com
- Update to 0.161
* Tue Aug 12 2014 ncutler@suse.com
- Update to 0.157
* Mon Aug 11 2014 ncutler@suse.com
- Update to 0.154
* Mon Aug 11 2014 ncutler@suse.com
- update build_requires
* Mon Aug 11 2014 ncutler@suse.com
- update dependencies
* Mon Aug 11 2014 ncutler@suse.com
- Update to 0.153
* Fri Aug  8 2014 ncutler@suse.com
- regenerated spec file to update dependencies
* Fri Aug  8 2014 ncutler@suse.com
- updated to 0.149
* Fri Aug  8 2014 ncutler@suse.com
- Update to 0.149
* Wed Aug  6 2014 ncutler@suse.com
- Update to 0.145
* Wed Aug  6 2014 ncutler@suse.com
- Update to 0.144
* Tue Aug  5 2014 ncutler@suse.com
- Update to 0.141
* Tue Aug  5 2014 ncutler@suse.com
- Update to 0.140
* Mon Aug  4 2014 ncutler@suse.com
- Update to 0.135
* Mon Aug  4 2014 ncutler@suse.com
- Update to 0.134
* Thu Jul 31 2014 ncutler@suse.com
- updated to 0.125, added new dependencies
* Thu Jul 31 2014 ncutler@suse.com
- Update to 0.125
* Thu Jul 31 2014 ncutler@suse.com
- Update to 0.122
* Wed Jul 30 2014 ncutler@suse.com
- Update to 0.117
* Wed Jul 30 2014 ncutler@suse.com
- Update to 0.116
* Wed Jul 30 2014 ncutler@suse.com
- Update to 0.115
* Tue Jul 29 2014 ncutler@suse.com
- Update to 0.114
* Mon Jul 28 2014 ncutler@suse.com
- Update to 0.109
* Mon Jul 28 2014 ncutler@suse.com
- Update to 0.108
* Mon Jul 28 2014 ncutler@suse.com
- Update to 0.107
* Mon Jul 28 2014 ncutler@suse.com
- updated to 0.106
* Mon Jul 28 2014 ncutler@suse.com
- Update to 0.106
* Fri Jul 25 2014 ncutler@suse.com
- Update to 0.099
* Thu Jul 24 2014 ncutler@suse.com
- Update to 0.098
* Thu Jul 24 2014 ncutler@suse.com
- Update to 0.097
* Thu Jul 24 2014 ncutler@suse.com
- Update to 0.096
* Thu Jul 24 2014 ncutler@suse.com
- Update to 0.095
* Thu Jul 24 2014 ncutler@suse.com
- Update to 0.093
* Wed Jul 23 2014 ncutler@suse.com
- Update to 0.090
* Wed Jul 23 2014 ncutler@suse.com
- Update to 0.089
* Wed Jul 23 2014 ncutler@suse.com
- Update to 0.088
* Wed Jul 23 2014 ncutler@suse.com
- spec file fix for CI
* Wed Jul 23 2014 ncutler@suse.com
- Update to 0.087
* Wed Jul 23 2014 ncutler@suse.com
- initial package 0.086
  * created by cpanspec 1.78.08
